$VAR1 = {
    'en' => {
        'insert'                  => 'Insert',
        'files'                   => 'Explorer',
        'openfile'                => 'Explorer',
        'editmysqluserrights'     => 'Database',
        'save'                    => 'Save',
        'rename'                  => 'Rename',
        'email'                   => 'Email Adress',
        'wrongusername'           => 'Wrong Username',
        'password'                => 'Password',
        'optionale email adresse' => 'Optionale email adresse',
        'edittable'               => 'Database',
        'admincenter'             => 'Admin',
        'logout'                  => 'Logout',
        'category'                => 'Category',
        'endtable'                => 'at end',
        'newmenu'                 => 'Create new Menu',
        'multipleaction'          => 'Database',
        'name'                    => 'Name',
        'details'                 => 'Details',
        'movetreeviewentry'       => 'TreeView',
        'dumpdatabase'            => 'Database',
        'properties'              => 'Properties',
        'trash'                   => 'Trash',
        'unselect_all'            => 'Select none',
        'translate'               => 'Translate',
        'showrights'              => 'Show rights',
        'delete'                  => 'Delete',
        'chars'                   => 'Chars left:',
        'editvmenu'               => 'Edit V-Menu',
        'links_pro_page'          => 'links/page',
        'non_unique'              => 'Non_unique',
        'saveedittable'           => 'Database',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'showfiles'            => 'Explorer',
        'deletefile'           => 'Explorer',
        'insertafter'          => 'After',
        'changecurrentdb'      => 'Change Database User',
        'cardinality'          => 'Cardinality',
        'createnewtable'       => 'Database',
        'pass'                 => 'Password',
        'edithmenu'            => 'Edit H-Menu',
        'truncate'             => 'Truncate',
        'showeditindex'        => 'Database',
        'editnavi'             => 'Edit Navigation',
        'edittableprops'       => 'Database',
        'sort'                 => 'Sort',
        'fields'               => 'Fields',
        'select_all'           => 'Select All',
        'index_type'           => 'Index_type',
        'profile'              => 'Profile',
        'next'                 => 'Next',
        'feeds'                => 'Rss Feeds',
        'importoperabookmarks' => 'Bookmarks',
        'upentry'              => 'Sort',
        'comments'             => 'Comments',
        'exportdatabase'       => 'Database',
        'newentry'             => 'New Entry',
        'editaction'           => 'Edit Action',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Explorer',
        'makedir'              => 'Explorer',
        'lostpass'             => 'Lost Password',
        'export'               => 'Export',
        'savefile'             => 'Explorer',
        'haveacount'           => 'You already have an Acount',
        'links'                => 'Sitemap',
        'savetreeviewentry'    => 'TreeView',
        'newindex'             => 'New Index',
        'admin'                => 'Admin',
        'addtreeviewentry'     => 'Add new entry',
        'failed: invalid code' => 'failed: invalid code',
        'newdir'               => 'Explorer',
        'createuser'           => 'Create User',
        'editentry'            => 'Edit Entry',
        'saverights'           => 'Database',
        'getpass'              => 'Lost Password',
        'null'                 => 'Null',
        'retry'                => 'retry',
        'exportoperabookmarks' => 'Bookmarks',
        'multipledbaction'     => 'Database',
        'preview'              => 'Preview',
        'bookmarks'            => 'Bookmarks',
        'type'                 => 'type',
        'repairtable'          => 'Database',
        'newpass'              => 'New Password',
        'rows in effect'       => 'rows in effect',
        'after'                => 'after',
        'city'                 => 'City',
        'column_name'          => 'Column_name',
        'showtables'           => 'Show Tables',
        'analyzetable'         => 'Analyze Table',
        'familyname'           => 'Family Name',
        'auswahl aufheben'     => 'Auswahl aufheben',
        't_regtext'            => 'Register',
        'back'                 => 'Back',
        'datenbank'            => 'datenbank',
        'readmore'             => 'Read More',
        'phone'                => 'Phone Number',
        'createindex'          => 'Database',
        'showtabledetails'     => 'Show Table Details',
        'navigation'           => 'Navigation',
        'register'             => 'Register',
        'mailsubject'          => 'Register',
        'permission denied'    => 'permission denied',
        'indexover'            => 'Indexover',
        'optimize'             => 'Optimize',
        'execsql'              => 'Exec Sql',
        'news'                 => 'Logbook',
        'headline'             => 'Headline',
        'rights'               => 'Rights',
        'edit entry'           => 'Edit Entry',
        'table'                => 'Table',
        'caption'              => 'Caption',
        'regmessage'           => 'You receive this email from Lindnerei.de',
        'newfile'              => 'Explorer',
        'folderfirst'          => 'Folder first',
        'sql'                  => 'SQL',
        'createtable'          => 'Create Table',
        'saveentry'            => 'Save Entry',
        'edittree'             => 'Edit',
        'username'             => 'User',
        'deletetreeviewentry'  => 'Delete',
        'showusers'            => 'Show Users',
        'changeautoincrementvalue' => 'Database',
        'showtable'                => 'Show Table',
        'explorer'                 => 'Explorer',
        'news_pro_page'            => 'News pro page',
        'optimizetable'            => 'Optimize Table',
        'welcome'                  => 'Welcome',
        'packed'                   => 'Packed',
        'newpost'                  => 'New Message',
        'edit'                     => 'Edit',
        'size'                     => 'Size',
        'body'                     => 'Body',
        'summary'                  => 'Summary',
        'edittreeviewentry'        => 'Editor',
        'editfile'                 => 'Editor',
        'newfileadded'             => 'New File created',
        'referer'                  => 'Referer',
        'create'                   => 'Create',
        'choosefile'               => 'Choose Attachment',
        'edit links'               => 'Edit Sitemap',
        'shownewentry'             => 'New Entry',
        'deleteentry'              => 'Delete Entry',
        'env'                      => 'Env',
        'repair'                   => 'Repair',
        'key_name'                 => 'Key_name',
        'database'                 => 'Database',
        'reg'                      => 'Register',
        'inserttext'               => 'Insert Text',
        'firstname'                => 'Firstname',
        'search'                   => 'Search',
        'done'                     => 'Done',
        'street'                   => 'Street',
        'insertpass'               => 'Insert Password',
        'edit table'               => 'Edit Table',
        'about'                    => 'About',
        'floodtext'                => 'To many Posts',
        'answers'                  => 'Answers',
        'field'                    => 'field',
        'show'                     => 'Show',
        'sites'                    => 'Sites',
        'truncatetable'            => 'Truncate',
        'nomail'                   => 'No Email Adress given.',
        'newcol'                   => 'New Column',
        'insertname'               => 'Insert Your Name',
        'fileexists'               => 'File already Exists',
        'newtreeviewentry'         => 'New Entry',
        'downentry'                => 'Sort',
        'buildfeeds'               => 'Rss Feeds',
        'kontaktsubjects'          => 'kontaktsubjects',
        'edittreeview'             => 'Edit',
        'newtable'                 => 'New Table',
        'userexits'                => 'This name is olready in use.<br/>',
        'wrongpass'                => 'Wrong Password',
        'starttable'               => 'at start',
        'impressum'                => 'Impressum',
        'sub_part'                 => 'sub_part',
        'gbook_body'               => 'Write your entry',
        'mysqldump'                => 'Mysql dump',
        'realy'                    => 'Realy',
        'help'                     => 'Help',
        'editmessage'              => 'Edit',
        'postcode'                 => 'Postcode',
        'gbook'                    => 'Gbook',
        'dumptable'                => 'Databases',
        'databases'                => 'Databases',
        'blog'                     => 'Logbook',
        'settings'                 => 'Settings',
        'seq_in_index'             => 'Seq_in_index',
        'reply'                    => 'Replies',
        'comment'                  => 'Comment',
        'action'                   => 'Action',
        'selected'                 => 'Select all',
        'newmessage'               => 'New Topic',
        'showwindow'               => 'Show Windows',
        'changeengine'             => 'Change Engine',
        'createdatabase'           => 'New Database',
        'showdatabases'            => 'Databases',
        'connect'                  => 'Connect',
        'dropdatabase'             => 'Drop Database',
        'importfirefox'            => 'Import FireFox Bookmarks',
        'dragsharelink'            => 'Drag link to your Bookmarks',
        'sharelink'                => 'Share',
        'newfolder'                => 'Append',
    },
    'de' => {
        'insert'              => 'Einf&#252;gen',
        'openfile'            => 'Explorer',
        'files'               => 'Explorer',
        'editmysqluserrights' => 'Datenbank',
        'save'                => 'Speichern',
        'rename'              => 'Umbenennen',
        'email'               => 'Email Adresse',
        'wrongusername' =>
            'Sie haben keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
        'optionale email adresse' => 'optionale email adresse',
        'password'                => 'Passwort',
        'edittable'               => 'Database',
        'admincenter'             => 'Admin',
        'logout'                  => 'Abmelden',
        'endtable'                => 'am ende',
        'category'                => 'Kategorie',
        'dein name'               => 'Dein name',
        'newmenu'                 => 'Neues Menu erstellen',
        'multipleaction'          => 'Datenbank',
        'name'                    => 'Name',
        'movetreeviewentry'       => 'TreeView',
        'details'                 => 'Details',
        'properties'              => 'Einstellungen',
        'dumpdatabase'            => 'Datenbank',
        'nachricht senden'        => 'Nachricht senden',
        'trash'                   => 'M&#252;lleimer',
        'unselect_all'            => 'Auswahl aufheben',
        'translate'               => '&#220;bersetzen',
        'showrights'              => 'Datenbank',
        'editvmenu'               => 'Vertikales Menu',
        'delete'                  => 'L&#246;schen',
        'chars'                   => 'Zeichen &#252;brig:',
        'sitemap'                 => '&#252;bersicht',
        'links_pro_page'          => 'Eintr&auml;ge/Seite',
        'non_unique'              => 'Nicht Unique',
        'saveedittable'           => 'Datenbank',
        'mailsendet' =>
            '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
        'showfiles'            => 'Explorer',
        'deletefile'           => 'Explorer',
        'insertafter'          => 'Einf&#252;gen',
        'changecurrentdb'      => 'Benutzer wechseln',
        'cardinality'          => 'Kardinalit&auml;t',
        'createnewtable'       => 'Neue Tabelle erstellen',
        'speichern'            => 'Speichern',
        'pass'                 => 'Passwort',
        'truncate'             => 'Leeren',
        'showeditindex'        => 'Datenbank',
        'edithmenu'            => 'Horizontales Menu',
        'editnavi'             => 'Navigation',
        'sort'                 => 'Sortieren',
        'edittableprops'       => 'Bearbeiten',
        'fields'               => 'Spalten',
        'select_all'           => 'Alle ausw&auml;hlen',
        'index_type'           => 'Type',
        'profile'              => 'Einstellungen',
        'next'                 => 'Weiter',
        'importoperabookmarks' => 'Opera Lezeichen importieren',
        'feeds'                => 'Rss',
        'upentry'              => 'TreeView',
        'exportdatabase'       => 'Datenbank',
        'comments'             => 'Kommentare',
        'newentry'             => 'Neuer Eintrag',
        'editaction'           => 'Aktion bearbeiten',
        'nachricht'            => 'nachricht',
        'chmodfile'            => 'Explorer',
        'makedir'              => 'Explorer',
        'lostpass'             => 'Passwort vergessen',
        'savefile'             => 'Speichern',
        'export'               => 'Exportieren',
        'haveacount'           => 'Sie haben bereits einen Acount',
        'savetreeviewentry'    => 'TreeView',
        'links'                => 'Sitemap',
        'newindex'             => 'Neuer Index',
        'failed: invalid code' => 'Fehler: falscher Captcha Code',
        'admin'                => 'Administrator',
        'addtreeviewentry'     => 'Hinzuf&#252;gen',
        'newdir'               => 'Explorer',
        'createuser'           => 'Benutzer erstellen',
        'editentry'            => 'Eintrag bearbeiten',
        'saverights'           => 'Datenbank',
        'getpass'              => 'Passwort vergessen',
        'null'                 => 'Null',
        'retry'                => 'Wiederholen',
        'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
        'multipledbaction'     => 'Datenbank',
        'preview'              => 'Vorschau',
        'bookmarks'            => 'Lesezeichen',
        'type'                 => 'type',
        'repairtable'          => 'Reparieren',
        'newpass'              => 'Neues Passwort',
        'rows in effect'       => 'rows in effect',
        'after'                => 'nach',
        'city'                 => 'Stadt',
        'column_name'          => 'Spalten Name',
        'showtables'           => 'Anzeigen',
        'analyzetable'         => 'Analysieren',
        'familyname'           => 'Nachname',
        'auswahl aufheben'     => 'Auswahl aufheben',
        't_regtext'            => 'Registrieren',
        'back'                 => 'zur&uuml;ck',
        'datenbank'            => 'Datenbank',
        'readmore'             => 'ganzen Atikel lesen',
        'phone'                => 'Telefonnummer',
        'showtabledetails'     => 'Details',
        'createindex'          => 'Index erstellen',
        'register'             => 'Registrieren',
        'navigation'           => 'Navigation',
        'mailsubject'          => 'Registrierung',
        'permission denied'    => 'Keine Berechtigung',
        'indexover'            => 'Index &#252;ber',
        'optimize'             => 'Optimieren',
        'news'                 => 'Logbook',
        'execsql'              => 'Sql ausf&uuml;hren',
        'headline'             => '&#220;berschrift',
        'rights'               => 'Rechte',
        'edit entry'           => 'Eintrag Bearbeiten',
        'table'                => 'Tabelle',
        'caption'              => '&#220;berschrift',
        'regmessage' =>
            'Sie ehalten diese Email weil versucht wurde sich auf damit bei uns zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
        'kontakt'                  => 'Kontakt',
        'sql'                      => 'SQL',
        'newfile'                  => 'Explorer',
        'lang'                     => 'de',
        'folderfirst'              => 'Verzeichnisse zuerst',
        'createtable'              => 'Tabelle erstellen',
        'saveentry'                => 'Eintrag speichern',
        'edittree'                 => 'Bearbeiten',
        'username'                 => 'Benutzer',
        'createtable'              => 'Tabelle erstellen',
        'deletetreeviewentry'      => 'Lösche',
        'showusers'                => 'Benutzer Anzeigen',
        'changeautoincrementvalue' => 'autoincrement wert &#228;ndern',
        'showtable'                => 'Tabelle Anzeigen',
        'explorer'                 => 'Explorer',
        'news_pro_page'            => 'Nachrichten/Seite',
        'optimizetable'            => 'Optimieren',
        'welcome'                  => 'Willkommen',
        'packed'                   => 'Gepackt',
        'newpost'                  => 'Neue Nachricht',
        'edit'                     => 'Bearbeiten',
        'size'                     => 'Gr&ouml;&szlig;e',
        'body'                     => 'Text',
        'summary'                  => 'Zusammenfassung',
        'edittreeviewentry'        => 'Bearbeiten',
        'editfile'                 => 'Datei bearbeiten',
        'newfileadded'             => 'Neue Datei wurde erstellt',
        'referer'                  => 'Referer',
        'edit links'               => 'Sitemap bearbeiten',
        'create'                   => 'Erstellen',
        'choosefile'               => 'File ausw&#228;hlen',
        'shownewentry'             => 'Neuer Eintrag',
        'deleteentry'              => 'Eintrag l&#246;schen',
        'env'                      => 'Variablen',
        'repair'                   => 'Reparieren',
        'key_name'                 => 'Schl&uuml;ssel',
        'database'                 => 'Datenbank',
        'reg'                      => 'Registrieren',
        'inserttext'               => 'Text einf&#252;gen',
        'firstname'                => 'Vorname',
        'search'                   => 'Suchen',
        'done'                     => 'Gespeichert',
        'street'                   => 'Strasse',
        'insertpass'               => 'Passwort eingeben',
        'edit table'               => 'Bearbeiten',
        'about'                    => '&#220;ber',
        'floodtext'                => 'Nicht so oft posten',
        'field'                    => 'field',
        'answers'                  => 'Antworten',
        'sites'                    => 'Seiten',
        'show'                     => 'Anzeigen',
        'truncatetable'            => 'truncatetable',
        'nomail'           => 'Sie haben keine email adresse angegeben.',
        'newcol'           => 'Neue Zeile',
        'insertname'       => 'Namen eingeben',
        'fileexists'       => 'Datei existiert bereits',
        'newtreeviewentry' => 'Neuer Eintrag',
        'downentry'        => 'TreeView',
        'buildfeeds'       => 'Rss',
        'userexits' =>
            'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
        'newtable'       => 'Neue Tabelle',
        'edittreeview'   => 'Bearbeiten',
        'wrongpass'      => 'Falsches Passwort',
        'starttable'     => 'am Anfang',
        'daten'          => 'Daten',
        'alle markieren' => 'Alle markieren',
        'sub_part'       => 'Sub Part',
        'impressum'      => 'Impressum',
        'gbook_body'     => 'Text einf&#252;gen',
        'mysqldump'      => 'Mysql dump',
        'realy'          => 'Wirklich',
        'help'           => 'Hilfe',
        'postcode'       => 'Postleitzahl',
        'editmessage'    => 'Bearbeiten',
        'gbook'          => 'G&#228;stebuch',
        'dumptable'      => 'Tabelle exportieren',
        'databases'      => 'Datenbanken',
        'blog'           => 'Weblog',
        'settings'       => 'Settings',
        'seq_in_index'   => 'seq_in_index',
        'reply'          => 'Antworten',
        'shownewtable'   => 'Neue Tabelle',
        'comment'        => 'Kommentar',
        'selected'       => 'Alle ausw&#228;hlen',
        'showwindow'     => 'Fenster anzeigen',
        'newmessage'     => 'Neue Nachricht',
        'changeengine'   => 'Engine &#228;ndern',
        'showdatabases'  => 'Datenbanken',
        'createdatabase' => 'Neue Datenbank',
        'connect'        => 'Verbinden',
        'dropdatabase'   => 'Datenbank löschen',
        'importfirefox'  => 'Firefox Lesezeichen importieren',
        'dragsharelink'  => 'Ins lesezeichen Menu ziehen',
        'sharelink'      => 'Teilen',
        'newfolder'      => 'Anh&#228;ngen',
    }
};
$lang = $VAR1;
